sqlobject.tests.test_joins_conditional module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_joins_conditional module

class `sqlobject.tests.test_joins_conditional.` `SOTestJoin1`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `col1`
  `j` = so_test_join1
  `q` = so_test_join1
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_joins_conditional.SOTestJoin1`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_join1'

class `sqlobject.tests.test_joins_conditional.` `SOTestJoin2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `col2`
  `j` = so_test_join2
  `q` = so_test_join2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_joins_conditional.SOTestJoin2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_join2'

class `sqlobject.tests.test_joins_conditional.` `SOTestJoin3`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `col3`
  `j` = so_test_join3
  `q` = so_test_join3
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_joins_conditional.SOTestJoin3`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_join3'

class `sqlobject.tests.test_joins_conditional.` `SOTestJoin4`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `col4`
  `j` = so_test_join4
  `q` = so_test_join4
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_joins_conditional.SOTestJoin4`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_join4'

class `sqlobject.tests.test_joins_conditional.` `SOTestJoin5`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `col5`
  `j` = so_test_join5
  `q` = so_test_join5
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_joins_conditional.SOTestJoin5`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_join5'

`sqlobject.tests.test_joins_conditional.` `setup`()

`sqlobject.tests.test_joins_conditional.` `test_1syntax`()

`sqlobject.tests.test_joins_conditional.` `test_2select_syntax`()

`sqlobject.tests.test_joins_conditional.` `test_3perform_join`()

`sqlobject.tests.test_joins_conditional.` `test_4join_3tables_syntax`()

`sqlobject.tests.test_joins_conditional.` `test_5join_3tables_syntax2`()

`sqlobject.tests.test_joins_conditional.` `test_6join_using`()

`sqlobject.tests.test_joins_conditional.` `test_7join_on`()